"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndentedStringWriter = void 0;
/**
 * Provides a text writer that can indent new lines by a tab string token.
 */
class IndentedStringWriter {
    /**
     * Creates an instance of the IndentedStringWriter class.
     * @param indentSize the initial indent size in spaces.
     */
    constructor(indentSize = 2) {
        this._buffer = [];
        this._indentLevel = 0;
        this._offset = "";
        this._eol = "\r\n";
        this._indentSize = indentSize;
    }
    /**
     * Gets the current indent level.
     */
    get indentLevel() {
        return this._indentLevel;
    }
    /**
     * Sets the current indent level.
     */
    set indentLevel(value) {
        this._indentLevel = value < 0 ? 0 : value;
        this._offset = " ".repeat(this._indentLevel * this._indentSize);
    }
    /**
     * Gets the inner buffer array.
     */
    get buffer() {
        return this._buffer;
    }
    /**
     * Puts the tab string according to the indent level.
     */
    outputTabs() {
        this._buffer.push(this._offset);
        return this;
    }
    /**
     * Writes the specified string values followed by a line terminator, to the buffer.
     * @param values The string values to write.
     */
    writeLine(...values) {
        this._buffer.push(this._offset);
        values.forEach(v => this._buffer.push(v));
        this._buffer.push(this._eol);
        return this;
    }
    /**
     * Writes the specified string values followed by a line terminator without tabs, to the buffer.
     * @param values The string values to write.
     */
    writeLineNoTabs(...values) {
        values.forEach(v => this._buffer.push(v));
        this._buffer.push(this._eol);
        return this;
    }
    /**
     * Writes the specified string values to the buffer.
     * @param values The string values to write.
     */
    write(...values) {
        values.forEach(v => this._buffer.push(v));
        return this;
    }
    /**
     * Increases the indent level.
     */
    indent() {
        this.indentLevel++;
        return this;
    }
    /**
     * Decreases the indent level.
     */
    unindent() {
        this.indentLevel--;
        return this;
    }
    /**
     * Generate a string representation of the writer inner buffer.
     */
    toString() {
        return this._buffer.join("");
    }
}
exports.IndentedStringWriter = IndentedStringWriter;
